<?php
/** Yoruba (Yorùbá)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Demmy
 * @author Meno25
 * @author Urhixidur
 */

$namespaceNames = array(
	NS_MEDIA            => 'Amóhùnmáwòrán',
	NS_SPECIAL          => 'Pàtàkì',
	NS_TALK             => 'Ọ̀rọ̀',
	NS_USER             => 'Oníṣe',
	NS_USER_TALK        => 'Ọ̀rọ̀_oníṣe',
	NS_PROJECT_TALK     => 'Ọ̀rọ̀_$1',
	NS_FILE             => 'Àwòrán',
	NS_FILE_TALK        => 'Ọ̀rọ̀_àwòrán',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'Ọ̀rọ̀_mediaWiki',
	NS_TEMPLATE         => 'Àdàkọ',
	NS_TEMPLATE_TALK    => 'Ọ̀rọ̀_àdàkọ',
	NS_HELP             => 'Ìrànlọ́wọ́',
	NS_HELP_TALK        => 'Ọ̀rọ̀_ìrànlọ́wọ́',
	NS_CATEGORY         => 'Ẹ̀ka',
	NS_CATEGORY_TALK    => 'Ọ̀rọ̀_ẹ̀ka',
);

$messages = array(
# User preference toggles
'tog-underline'            => 'Fàlàsí àwọn ijápọ̀:',
'tog-justify'              => "S'àlàyé gbólóhùn ọ̀rọ̀",
'tog-hideminor'            => "Bo àtúnse kékékèé mọ́'lẹ̀ nínú àtúnse tuntun",
'tog-extendwatchlist'      => "Fífẹ̀ ìmójútó láti ṣ'àfihàn gbogbo àtúnṣe tó ṣẹ́lẹ̀",
'tog-editondblclick'       => "Ṣ'àtúnṣe àwọn ojúewé ní kíkàn lẹ́mẹjì (JavaScript)",
'tog-editsection'          => 'Jọ̀wọ́ àtúnṣe abala láti inú àwọn ìjápọ̀',
'tog-rememberpassword'     => "Sè'rántí ọ̀rọ̀ìpamí mi lórí kọmputa yi",
'tog-watchcreations'       => "S'àfikún ojúewé tí mo dá mọ́ ìmójútó mi",
'tog-watchdefault'         => "S'àfikún ojúewé tí mo s'àtúnse mọ́ ìmójútó mi",
'tog-watchmoves'           => "S'àfikún ojúewé tí mo kó kúrò mọ́ ìmójútó mi",
'tog-watchdeletion'        => "S'àfikún ojúewé tí mo parẹ́ mọ́ ìmójútó mi",
'tog-minordefault'         => "Se àmì sí gbogbo àtúnse gẹ́gẹ́ bi kékeré lát'ìbẹ̀rẹ̀.",
'tog-previewontop'         => "Se àyẹ̀wò kí ẹ tó s'àtúnṣe",
'tog-previewonfirst'       => "S'àfihàn àgbéwò fún àtúnse àkọ́kọ́",
'tog-nocache'              => "D'ènà fífi ojúewé pamọ́",
'tog-enotifwatchlistpages' => 'Fi e-mail ránsẹ́ sími tí ojúewé tí mò ún mójútó bá yípadà',
'tog-enotifusertalkpages'  => 'Fi e-mail ránsẹ́ sími tí ojúewé ẹnitínse mi bá yípadà',
'tog-enotifminoredits'     => 'Fi e-mail ránsẹ́ sími bákannà fún àtúnse kékékèé sí ojúewé',
'tog-enotifrevealaddr'     => "Ṣ'àfihàn ojúọ̀nà e-mail mi nínú àwọn ìránṣẹ́ e-mail",
'tog-shownumberswatching'  => "S'àfihàn iye àwọn ẹnitínse tí wọn ún mójútó",
'tog-forceeditsummary'     => 'Kìlọ̀ fún mi tí àkótán àtúnṣe bá jẹ́ òfo',
'tog-watchlisthideown'     => 'Ìbòmọ́lẹ̀ àwọn àtúnṣe mi nínú ìmójútó',
'tog-watchlisthidebots'    => 'Ìbòmọ́lẹ̀ àwọn àtúnṣe bot nínú ìmójútó',
'tog-watchlisthideminor'   => 'Ìbòmọ́lẹ̀ àwọn àtúnṣe kéékèké nínú ìmójútó',
'tog-ccmeonemails'         => 'Ìfiránṣẹ́ sími àwọn àwòkọ àwọn e-mail tí mo firánṣẹ́ sí àwọn oníṣe míràn',
'tog-showhiddencats'       => "Ṣ'àfihàn àwọn ẹ̀ka tó pamọ́",

'underline-always' => 'Nígbà gbogbo',

# Dates
'sunday'        => 'Ọjọ́àìkú',
'monday'        => 'Ọjọ́ajé',
'tuesday'       => 'Ọjọ́ìsẹ́gun',
'wednesday'     => 'Ọjọ́rú',
'thursday'      => 'Ọjọ́bọ̀',
'friday'        => 'Ọjọ́ẹtì',
'saturday'      => 'Ọjọ́àbámẹ́ta',
'sun'           => 'Àìkú',
'mon'           => 'Ajé',
'tue'           => 'Ìṣẹ́gun',
'wed'           => 'Rú',
'thu'           => 'Bọ̀',
'fri'           => 'Ẹtì',
'sat'           => 'Àbámẹ́ta',
'january'       => 'January',
'february'      => 'February',
'march'         => 'March',
'april'         => 'April',
'may_long'      => 'May',
'june'          => 'June',
'july'          => 'July',
'august'        => 'August',
'september'     => 'September',
'october'       => 'October',
'november'      => 'November',
'december'      => 'December',
'january-gen'   => 'January',
'february-gen'  => 'February',
'march-gen'     => 'March',
'april-gen'     => 'April',
'may-gen'       => 'May',
'june-gen'      => 'June',
'july-gen'      => 'July',
'august-gen'    => 'August',
'september-gen' => 'September',
'october-gen'   => 'October',
'november-gen'  => 'November',
'december-gen'  => 'December',
'jan'           => 'Jan',
'feb'           => 'Feb',
'mar'           => 'Mar',
'apr'           => 'Apr',
'may'           => 'May',
'jun'           => 'Jun',
'jul'           => 'Jul',
'aug'           => 'Aug',
'sep'           => 'Sep',
'oct'           => 'Oct',
'nov'           => 'Nov',
'dec'           => 'Dec',

# Categories related messages
'pagecategories'           => '{{PLURAL:$1|Ẹ̀ka|Àwọn ẹ̀ka}}',
'category_header'          => 'Àwọn ojúewé nínú ẹ̀ka "$1"',
'subcategories'            => 'Àwọn abẹẹ̀ka',
'category-media-header'    => 'Amóunmáwòrán nínú ẹ̀ka "$1"',
'category-empty'           => "''Lọ́wọ́lọ́wọ́ ẹ̀ka yìí kò ní ojúewé tàbí amóhùnmáwòrán kankan.''",
'hidden-categories'        => '{{PLURAL:$1|Ẹ̀ka àbòmọ́lẹ̀|Áwọn ẹ̀ka àbòmọ́lẹ̀}}',
'hidden-category-category' => 'Àwọn ẹ̀ka àbòmọ́lẹ̀', # Name of the category where hidden categories will be listed
'category-article-count'   => '{{PLURAL:$2|Ẹ̀ka yìí ní ojúewé kan péré.|{{PLURAL:$1|Ojúewé kan yìí nìkan|Àwọn ojúewé $1 yìí}} lówà nínú èka yìí, nínú àpapọ̀ $2.}}',
'listingcontinuesabbrev'   => 'tẹ̀síwájú',

'about'          => 'Nípa',
'newwindow'      => '(yíò sí nínú fèrèsè tuntun)',
'cancel'         => "Fa'gilé",
'qbfind'         => 'Wá rí',
'qbbrowse'       => 'Ìṣíwò',
'qbedit'         => 'Àtúnṣe',
'qbpageoptions'  => 'Ojúewé yi',
'qbmyoptions'    => 'Àwọn ojúewé mi',
'qbspecialpages' => 'Àwọn ojúewé pàtàkì',
'moredotdotdot'  => 'Ẹ̀kúnrẹ́rẹ́...',
'mypage'         => 'Ojúewé mi',
'mytalk'         => 'Ọ̀rọ̀ mi',
'anontalk'       => 'Ọ̀rọ̀ fún IP yí',
'navigation'     => 'Atọ́ka',
'and'            => '&#32;àti',

# Metadata in edit box
'metadata_help' => 'Metadata:',

'errorpagetitle'    => 'Àsìse',
'returnto'          => 'Padà sí $1.',
'tagline'           => "Lát'ọwọ́ {{SITENAME}}",
'help'              => 'Ìrànlọ́wọ́',
'search'            => 'Ṣe àwáàrí',
'searchbutton'      => 'Ṣe àwáàrí',
'go'                => 'Ó yá',
'searcharticle'     => 'Ó yá',
'history'           => 'Ìtàn ojúewé',
'history_short'     => '
Ìtàn',
'updatedmarker'     => 'jẹ́ títúnṣe lẹ́yìn àbẹ̀wò mi',
'printableversion'  => 'Títẹ̀ sí ìwé',
'permalink'         => 'Ìjápọ̀ tíkòníyípadà',
'print'             => 'Tẹ̀síìwé',
'edit'              => 'Àtúnṣe',
'create'            => "Ṣè'dá",
'editthispage'      => "S'àtúnṣe ojúewé yi",
'create-this-page'  => "Ṣè'dá ojúewé yìí",
'delete'            => 'Paarẹ́',
'deletethispage'    => 'Pa ojúewé yi rẹ́',
'protect'           => 'Dábòbò',
'protect_change'    => 'yípadà',
'protectthispage'   => 'Dá àbò bo ojúewé yìí',
'unprotect'         => 'Mú àbò kúrò',
'unprotectthispage' => 'Mú àbò kúrò lórí ojúewé yìí',
'newpage'           => 'Ojúewé tuntun',
'talkpage'          => 'Kábárawasọ̀rọ̀ nípa ojúewé yi',
'talkpagelinktext'  => 'Kábárawasọ̀rọ̀',
'specialpage'       => 'Ojúewé Pàtàkì',
'personaltools'     => 'Àwọn irinṣẹ́ àdáni',
'postcomment'       => 'Ṣe àwísọ',
'talk'              => 'Ìfọ̀rọ̀wérọ̀',
'views'             => 'Àwọn ìwò',
'toolbox'           => 'Àpótí irinṣẹ',
'userpage'          => 'Wo ojúewé oníṣe',
'projectpage'       => 'Wo ojúewé iṣẹ́ọwọ́',
'imagepage'         => 'Wo ojúewé amóhùnmáwòrán',
'mediawikipage'     => 'Wo ojúewé ìránṣẹ́',
'templatepage'      => 'Wo ojúewé àdàkọ',
'viewhelppage'      => 'Wo ojúewé ìrànlọ́wọ́',
'categorypage'      => 'Wo ojúewé ẹ̀ka',
'viewtalkpage'      => 'Wo ìfọ̀rọ̀wérọ̀',
'otherlanguages'    => 'Àwọn èdè míràn',
'redirectedfrom'    => '(Àtúnjúwe láti $1)',
'redirectpagesub'   => 'Ojúewé àtúnjúwe',
'lastmodifiedat'    => 'Ọjọ́ tí a ṣe àtunṣe ojúewé yi gbẹ̀yìn ni $2, $1.', # $1 date, $2 time
'viewcount'         => 'A ti wo ojúewé yi ni {{PLURAL:$1|ẹ̀kan péré|iye ìgbà $1}}.',
'protectedpage'     => 'Ojúewé aláàbò',
'jumpto'            => 'Fò sí:',
'jumptonavigation'  => 'atọ́ka',
'jumptosearch'      => "
ṣ'àwáàrí",

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Nípa {{SITENAME}}',
'aboutpage'            => 'Project:Nípa',
'copyright'            => 'Gbogbo ohun inú ibí yi wà lábẹ́  $1.',
'copyrightpagename'    => '{{SITENAME}} ẹ̀tọ́àwòkọ',
'copyrightpage'        => '{{ns:project}}:Ẹ̀tọ́àwòko',
'currentevents'        => 'Ìròhìn nísinsìnyí',
'currentevents-url'    => 'Project:Ìròhìn nísinsìnyí',
'disclaimers'          => 'Ikìlọ̀',
'disclaimerpage'       => 'Project:Ìkìlọ̀ gbogbo',
'edithelp'             => "Ìrànlọ́wọ́ láti s'àtúnṣe",
'edithelppage'         => 'Help:Àtúnṣe',
'helppage'             => 'Help:Àwon ohunnú',
'mainpage'             => 'Ojúewé Àkọ́kọ́',
'mainpage-description' => 'Ojúewé Àkọ́kọ́',
'policy-url'           => 'Project:Ètò',
'portal'               => 'Èbúté àwùjọ',
'portal-url'           => 'Project:Èbúté Àwùjọ',
'privacy'              => 'Ètò àbò',
'privacypage'          => 'Project:Ètò àbò',

'badaccess-group0' => "A kò gbàyín l'áyè l'áti ṣe ohun tí ẹ bèrè fún.",

'ok'                      => 'OK',
'retrievedfrom'           => 'Kójáde láti "$1"',
'youhavenewmessages'      => 'Ẹ ní $1 ($2).',
'newmessageslink'         => 'ìfọ̀rọ̀ránsẹ́ tuntun',
'newmessagesdifflink'     => 'àtúnṣe ìgbẹ̀yìn',
'youhavenewmessagesmulti' => 'Ẹ ní ìfọ̀rọ̀ránsẹ́ tuntun ni $1',
'editsection'             => "s'àtúnṣe",
'editold'                 => "s'àtúnṣe",
'viewsourceold'           => 'wo àmìọ̀rọ̀',
'editlink'                => 'àtúnṣe',
'editsectionhint'         => 'Abala àtúnṣe: $1',
'toc'                     => 'Ohunnú',
'showtoc'                 => 'fihàn',
'hidetoc'                 => 'bòmọ́lẹ̀',
'thisisdeleted'           => 'Wo tàbí múpadà $1?',
'viewdeleted'             => 'Wo $1?',
'restorelink'             => '{{PLURAL:$1|àtúnṣe tóparẹ́ kan|àtúnṣe tóparẹ́ $1}}',
'feedlinks'               => 'Feed:',
'site-rss-feed'           => '$1 RSS Feed',
'site-atom-feed'          => '$1 Atom Feed',
'page-rss-feed'           => '"$1" RSS Feed',
'page-atom-feed'          => '"$1" Atom Feed',
'red-link-title'          => '$1 (kò sí ojúewé yìí)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Àyọkà',
'nstab-user'      => 'Ojúewé oníṣe',
'nstab-media'     => 'Ojúewé amóhùnmáwòrán',
'nstab-special'   => 'Ojúewé pàtàkì',
'nstab-project'   => 'Ojúewé iṣẹ́ọwọ́',
'nstab-image'     => 'Faili',
'nstab-mediawiki' => 'Ìfọ̀rọ̀ránsẹ',
'nstab-template'  => 'Àdàkọ',
'nstab-help'      => 'Ojúewé ìrànlọ́wọ́',
'nstab-category'  => 'Ẹ̀ka',

# Main script and global functions
'nosuchaction'      => 'Kò sí irú ìgbéṣe báun',
'nosuchactiontext'  => 'Ìgbéṣe tí URL yìí tọ́kasí kò ní ìdámọ̀ lórí wiki yìí',
'nosuchspecialpage' => 'Kò sí irú ojúewé pàtàkì báun',
'nospecialpagetext' => "<big>'''Ẹ tọrọ ojúewé pàtàkì tólòdì.'''</big>

Àkójọ àwọn ojúewé pàtàkì tóbámu wà ní [[Special:SpecialPages|{{int:specialpages}}]].",

# General errors
'error'                => 'Àsìṣe',
'missingarticle-rev'   => '(àtúnyẹ̀wò#: $1)',
'missingarticle-diff'  => '(Ìyàtọ̀: $1, $2)',
'filecopyerror'        => 'Àwòkọ faili "$1" sí "$2" kò ṣe é ṣe.',
'filerenameerror'      => 'Àtúnsọlórúkọ faili "$1" sí "$2" kò ṣe é ṣe.',
'filedeleteerror'      => 'Ìparẹ́ faili "$1" kò ṣe é ṣe.',
'directorycreateerror' => 'Ìwé-ìjúwe "$1" kò ṣe é ṣe.',
'filenotfound'         => 'Kò le é ṣe àwáàrí faili "$1".',
'badtitle'             => 'Àkọ́lé burúkú',
'badtitletext'         => 'Àkọlé ojúewé tí ẹ bèrè fún kò ní ìbámu, jẹ́ òfo, tàbí áṣìṣe wà nínú ìjápọ̀ àkọlé láàrin èdè tàbí láàrin wiki.
Ó ṣe é ṣe kó jẹ́pé ó ní ìkan tàbí ọ̀pọ̀ àmi lẹ́tà tí kò ṣe é lò nínú àkọlé.',
'viewsource'           => 'Àfihàn ọ̀rọ̀àmì',
'viewsourcefor'        => 'fún $1',
'protectedpagetext'    => 'A ti se àtìpa ojúewé yi. Ẹ kò le se àtúnṣe.',
'viewsourcetext'       => 'Ẹ lè wo ati ẹ lè se àwòkọ ọ̀rọ̀àmì ojúewé yi:',
'namespaceprotected'   => "A kò gbàyín ní ààyè láti ṣ'àtúnṣe àwọn ojúewé tó wà nínú orúkọàyè '''$1'''.",
'ns-specialprotected'  => 'Àtúnṣe kò ṣe é ṣe sí àwọn ojúewé pàtàkì.',
'titleprotected'       => "This title has been protected from creation by [[User:$1|$1]]. The reason given is ''$2''.",

# Login and logout pages
'logouttitle'               => 'Ibọsóde oníṣe',
'logouttext'                => "'''Ẹ ti bọ́sọ́de.'''

Ẹ le tẹ̀síwájú sí ní lo {{SITENAME}} láìmorúkọ yín, tàbí kí ẹ [[Special:UserLogin|padà wọlé]] bí ẹnikanan tàbí ẹlòmíràn.
Àkíyèsí wípé àwọn ojúewé kan le hàn b'ígbà tójẹ́pé ẹ sì wọlé títí tí ẹ ó fi jọ̀wọ́ àdìmú (cache) browser yín.",
'welcomecreation'           => "== Ẹ kú àbọ̀, $1! ==

A ti fi orúkọ yín s'ílẹ̀. Ẹ mọ́ gbàgbé l'áti s'àtúnṣe àwọn ìfẹ́ràn {{SITENAME}} yín.",
'loginpagetitle'            => 'Ìwọlé oníṣe',
'yourname'                  => 'Orúkọ oníṣe (username):',
'yourpassword'              => 'Ọ̀rọ̀ìpamọ́:',
'yourpasswordagain'         => 'Tẹkíkọ ọ̀rọ̀ìpamọ́ lẹ́ẹ̀kansí:',
'remembermypassword'        => "Sè'rántí ọ̀rọ̀ìpamí mi lórí kọmputa yi (cookies)",
'yourdomainname'            => 'Domain yín:',
'login'                     => 'Ìwọlé',
'nav-login-createaccount'   => 'Ìwọlé / Ìforúkọ sílẹ̀',
'loginprompt'               => 'Ẹ gbọ́dọ̀ jọ̀wọ́ cookies láti wọlé sí {{SITENAME}}.',
'userlogin'                 => 'Ìwọlé / ìforúkọ sílẹ̀',
'logout'                    => 'Ìbọ́sóde',
'userlogout'                => 'Ìbọ́sóde',
'notloggedin'               => "Ẹ kò tí w'ọlé",
'nologin'                   => 'Ṣé ẹ fẹ́ wọlé? $1.',
'nologinlink'               => 'Ẹ fi orúkọ sílẹ̀',
'createaccount'             => 'Ẹ fi orúkọ sílẹ̀',
'gotaccount'                => 'Ṣé ẹ ti ní àpamọ́ tẹ́lẹ̀? $1.',
'gotaccountlink'            => "Ẹ w'ọlé",
'createaccountmail'         => 'pẹ̀lú e-mail',
'badretype'                 => 'Àwọn ọ̀rọ̀ìpamọ́ tí ẹ kọ kò jọ ra wọn.',
'youremail'                 => 'E-mail:',
'username'                  => 'Orúkọ oníṣe:',
'uid'                       => 'Nọmba ìdámọ̀ fún ẹnitínṣe:',
'yourrealname'              => 'Orúkọ ganangan:',
'yourlanguage'              => 'Èdè:',
'yournick'                  => 'Ìtọwọ́bọ̀:',
'badsiglength'              => 'Ìtọwọ́bọ̀ yín ti gùnjù.
Kò gbodọ̀ ju $1 {{PLURAL:$1|àmìlẹ́tà|àwọn àmìlẹ́tà}} lọ.',
'email'                     => 'E-mail',
'prefs-help-realname'       => 'Orúkọ gangan kò pọndandan.
Tí ẹ bá fisílẹ̀ a ó lòó láti tóka iṣẹ́ yín fún yín.',
'loginerror'                => 'Àsìṣe ìwọlé',
'prefs-help-email-required' => 'E-mail ṣe dandan.',
'noname'                    => 'Ẹ kò tọ́kasí orúkọ oníṣe tó ní ìbámu.',
'loginsuccesstitle'         => 'Ìwọlé ti yọrí sí rere',
'loginsuccess'              => "'''Ẹ ti wọlé sínú {{SITENAME}} gẹ́gẹ́ bi \"\$1\".'''",
'nosuchuser'                => 'Kò sí oníṣe kankan pẹ̀lú orúkọ "$1".
Ẹ yẹ lẹ́tà yín wò, tàbí [[Special:UserLogin/signup|kí ẹ s\'èdá àpamọ́ tuntun]].',
'nosuchusershort'           => "Kò sí oníṣe t'ón jẹ́ <nowiki>$1</nowiki>.
Ẹ wo spelling yín.",
'nouserspecified'           => 'Ẹ gbọ́dọ̀ tọ́kasí orúkọ oníṣe kan.',
'wrongpassword'             => 'Ọ̀rọ̀ìpamọ́ tí ẹ kìbọ́ kòtọ́.
Ẹ jọ̀wọ́ ẹ gbìyànjú lẹ́ẹ̀kansí.',
'wrongpasswordempty'        => 'Ọ̀ròìpamọ́ jẹ́ òfo.
Ẹ gbìyànjú lẹ́ ẹ̀kan síi.',
'passwordtooshort'          => 'Ọ̀rọ̀ìpamọ́ yín jẹ́ aláìtọ́ tàbí ó kúrú ju bóṣe yẹ lọ.
Kò gbọ́dọ̀ dín ju {{PLURAL:$1|àmìlẹ́tà kan|àmìlẹ́tà $1}} lọ, kí ó sì yàtọ̀ sí oríkọoníṣe yín.',
'mailmypassword'            => 'Ọ̀rọ̀ìpamọ́ tuntun sí e-mail',
'passwordremindertitle'     => 'Ọ̀rọ̀ìpamọ́ tuntun fún ìgbà díẹ̀ fún {{SITENAME}}',
'passwordremindertext'      => 'Ẹnìkan (ó ṣe é ṣe kó jẹ́ ẹ̀yin gan, láti ojúọ̀ná IP $1) bèrè fún 
ọ̀rọ̀ìpamọ́ tuntun fùn {{SITENAME}} ($4). A ti ṣ\'èdá ọ̀rọ̀ìpamọ́ ìgbádíẹ̀ fún
oníṣe "$2" bẹ́ ẹ̀ sì ni a ti ṣ\'ètò rẹ̀ sí "$3". Tó bá jẹ́ pé èrò yín nuhun, ẹ gbúdọ̀ wọlé 
kí ẹ yan ọ̀rọ̀ìpamọ́ tuntun ní ìsinsìnyí. Ọ̀rọ̀ìpamọ́ ìgbàdíẹ̀ yín yíò parí lẹ́yìn ọjọ́ {{PLURAL:$5|kan|$5}}. 

Tó bá jẹ́ pé ẹlòmíràn ni ò ṣe ìtọrọ yìí, tábí pé ẹ ti rántí ọ̀rọ̀ìpamọ́ yín,
tí ẹ kò sì fẹ́ yípadà mọ́, ẹ mọ́ kọbiara sí ìránṣẹ́ yìí.',
'noemail'                   => 'Kò sí àkọsílẹ̀ ojúọ̀nà e-mail fún oníṣe "$1".',
'passwordsent'              => 'A ti fi ọ̀rọ̀ìpamọ́ tuntun ránṣẹ́ sí ojúọ̀nà e-mail tí a fisílẹ̀ fún "$1".
Ẹ jọ̀wọ́ ẹ padà wọlé tí ẹ bá ti gbàá.',
'eauthentsent'              => 'A ti fi e-mail ìmúdájú ránṣẹ́ sí ojúọ̀nà e-mail tí ẹ fi sílẹ̀.
Kí á tó fi e-mail mìíràn ránṣẹ́ sí àpamọ́ yìí, ẹ gbọ́dọ̀ tẹ̀lé àwọn ìlànà inú e-mail ọ̀ún, láti fidájú pé àpamọ́ ọ̀ún jẹ́ ti yín lóòótọ́.',
'emailauthenticated'        => 'Ojúọ̀nà e-mail yín fidájú ní ago $3 ọjọ́ $2.',
'emailconfirmlink'          => 'Ẹ ṣe ìmúdájú ojúọ̀nà e-mail yín',
'accountcreated'            => 'Ẹ ti fi orúkọ sílẹ̀',
'accountcreatedtext'        => "A ti ṣ'èdá àpamọ́ oniṣe fún $1.",
'createaccount-title'       => 'Ìforúkọ sílẹ̀ fún {{SITENAME}}',
'loginlanguagelabel'        => 'Èdè: $1',

# Password reset dialog
'resetpass'         => 'Àyípadà ọ̀rọ̀ìpamọ́',
'resetpass_header'  => "Ẹ ṣ'àyípadà ọ̀rọ̀ìpamọ́",
'oldpassword'       => 'Ọ̀rọ̀ìpamọ́ titẹ́lẹ̀:',
'newpassword'       => 'Ọ̀rọ̀ìpamọ́ tuntun:',
'retypenew'         => 'Àtúntẹ̀ ọ̀rọ̀ìpamọ́ tuntun:',
'resetpass_success' => 'Ìyípadà ọ̀rọ̀ìpamọ́ yín ti já sí rere! Ẹ̀ ún wọlé lọ́wọ́...',

# Edit page toolbar
'bold_sample'     => 'Ìkọ kedere',
'bold_tip'        => 'Ìkọ kedere',
'italic_sample'   => 'Ìkọ italiki',
'italic_tip'      => 'Ìkọ italiki',
'link_sample'     => 'Àkọlé ìjápọ̀',
'link_tip'        => "Ìjápọ̀ s'ínú",
'extlink_sample'  => 'http://www.example.com àkọlé ìjápọ̀',
'extlink_tip'     => "Ìjápọ̀ s'íta (ẹ mọ́ gbàgbé http:// prefix)",
'headline_sample' => 'Ìkọ àkọlé',
'headline_tip'    => 'Àkọlé onípele 2',
'math_sample'     => "Ẹ fi àgbékalẹ̀ s'íhín",
'math_tip'        => 'Àgbékalẹ̀ ìsirò (LaTeX)',
'nowiki_sample'   => "Ẹ fi ìkọ tí kò létò s'íhín",
'nowiki_tip'      => 'Ẹ fojú fo étò wiki',
'image_tip'       => 'Faili tí a kìbọ̀',
'media_tip'       => 'Ìjápọ̀ faili',
'sig_tip'         => 'Ìtọwọ́bọ̀ yín pẹ̀lú àmì-àsìkò',
'hr_tip'          => 'Ìlà gbọlọjọ (ẹ lọ̀ọ́ pẹ̀lú àkíyèsì)',

# Edit pages
'summary'                => 'Àkótán:',
'subject'                => 'Orí ọ̀rọ̀/àkọlé:',
'minoredit'              => 'Àtúnṣe kékeré nìyí',
'watchthis'              => "M'ójútó ojúewé yìí",
'savearticle'            => 'Ẹ fi pamọ́',
'preview'                => 'Àyẹ̀wò',
'showpreview'            => 'Àyẹ̀wò',
'showdiff'               => 'Àfihàn àwọn àyípadà',
'anoneditwarning'        => "'''Ìkìlọ̀:''' Ẹ ò tíì wọlé.
Á ṣe àkọsílẹ̀ ojúọ̀nà IP yín ninu ìwé àtúnṣe ojúewé yìí.",
'summary-preview'        => 'Àyẹ̀wò àkótán:',
'blockedtitle'           => 'Ìdènà sí oníṣe',
'blockedtext'            => "<big>'''A ti dínà orúkọ oníṣe tàbí ojúọ̀nà IP yín.'''</big>

$1 ni ó ṣe ìdínà.
Ìdí tó fun ni ''$2''.

* Ìbẹ̀rẹ̀ ìdínà: $8
* Ìparí ìdínà: $6
* Ẹni tí a fẹ́ dínà: $7

Ẹ ṣ'èránṣẹ́ sí $1 tàbí [[{{MediaWiki:Grouppage-sysop}}|alámùójútó]] mìíràn láti fọ̀rọ̀wérọ̀ lórí ìdínà ọ̀ún.
Ẹ kò le è 'ránṣẹ́ sí oníṣe yìí pẹ̀lú e-mail' àyàfi tí ojúọ̀nà e-mail tó dájú wà ní [[Special:Preferences|àwọn ìfẹ́ràn àpamọ́]] yín tí wọn kò sì ti dínà yín láti lò ó.
Ojúọ̀nà IP yín lọ́wọ́lọ́wọ́ ni $3, bẹ́ ẹ̀ sì ni ID fún ìdínà yín ni #$5.
Ẹ jọ̀wọ́ ẹ fi gbogbo ẹ̀kúnrẹ́rẹ́ òkè yìí kún ìbérè tí ẹ bá ṣe.",
'whitelistedittitle'     => "Ìwọlé ṣe dandan láti ṣ'àtúnṣe",
'whitelistedittext'      => "Ẹ gbọ́dọ̀ $1 láti ṣ'àtúnṣe àwọn ojúewé.",
'confirmedittitle'       => "Ìmúdájú E-mail ṣe dandan láti ṣ'àtúnṣe",
'nosuchsectiontitle'     => 'Kò sí irú abala báun',
'loginreqtitle'          => "Ẹ gbọ́dọ̀ kọ́kọ́ w'ọlé ná",
'loginreqlink'           => 'ìwọlé',
'loginreqpagetext'       => 'Ẹ gbọ́dọ̀ $1 láti wo àwọn ojúewé míràn.',
'accmailtitle'           => 'Ti fi ọ̀rọ̀ìpamọ́ ránṣẹ́.',
'accmailtext'            => 'A ti fi ọ̀rọ̀ìpamọ́ fún "$1" ránṣẹ́ sí $2.',
'newarticle'             => '(Tuntun)',
'newarticletext'         => "Ẹ ti tẹ̀lé ìjápọ̀ mọ́ ojúewé tí kò sí.
Láti dá ojúewé yí ẹ bẹ̀rẹ̀ síní tẹ́kọ sí inú àpótí ìsàlẹ̀ yí (ẹ wo [[{{MediaWiki:Helppage}}|ojúewé ìrànlọ́wọ́ ]] fun ẹ̀kúnrẹ́rẹ́ ).
T'óbá sepé àsìse ló gbé yin dé bi, ẹ kọn bọ́tìnì ìpadàsẹ́yìn.",
'noarticletext'          => "Lọ́wọ́lọ́wọ́ kò sí ìkọ nínú ojúewé yìí. 
Ẹ le [[Special:Search/{{PAGENAME}}|s'àwáàrí fún àkọlé ojúewé yìí]] nínú àwọn ojúewé mìíràn,
<span class=\"plainlinks\">[{{fullurl:Special:Log|page={{urlencode:{{FULLPAGENAME}}}}}} s'àwáàrí àkọọ́lẹ̀ rẹ̀], tàbí [{{fullurl:{{FULLPAGENAME}}|action=edit}} kí ẹ ṣ'àtúnṣe ojúewé òún]</span>.",
'note'                   => "'''Àkíyèsí:'''",
'previewnote'            => "'''Àyẹ̀wò kan ni èyí;
àwọn àtúnṣe kò tíì pamọ́!'''",
'session_fail_preview'   => "'''Àforíjìn! A kò le gbésẹ̀ àtúnṣe yín nítorí ìpòfo data ìsinsìyí.
Ẹ jọ̀wọ́ ẹ gbìyànjú lẹ́ẹ̀kan si.
Tí kò bá sì tún ṣiṣẹ́, ẹ gbìyànjú láti [[Special:UserLogout|bọ̀sòde]] kí ẹ sì padá wọlé.'''",
'editing'                => 'Àtúnṣe sí $1',
'editingsection'         => 'Àtúnṣe sí $1 (abala)',
'yourdiff'               => 'Àwọn ìyàtọ̀',
'copyrightwarning'       => "Ẹ jọ̀wọ́ ẹ kíyèsi wípé gbogbo àwọn àfikún sí {{SITENAME}} jẹ́ bẹ̀ lábẹ́  $2 (Ẹ wo $1 fún ẹkunrẹrẹ).
Tí ẹ kò bá fẹ́ kí ìkọọ́lẹ̀ yín ó jẹ́ títúnṣe tàbí kì ó jẹ́ pípìn kiri lọ́ná tí kò wù yín, ẹ mọ́ mù wá síbí.<br />
Bákannà ẹ tún ṣèlérí fún wa wípé ẹ̀yin lẹkọ́ fúnra arayín, tàbí ẹ wòókọ láti agbègbè ìgboro tàbí irú ìtìlẹ́yín ọ̀fẹ́ bíi bẹ́ẹ̀.
'''Ẹ MỌ́ MÚ IṢẸ́ TÓ NÍ Ẹ̀TỌ́ÀWÒKỌ SÍLẸ̀ LÁÌ GBÀṢẸ!'''",
'longpagewarning'        => "'''ÌKILỌ̀: Ojúewé yìí jẹ́ $1 kilobytes ní gúngùn;
àwọn browsers míràn le è ní ṣòro láti ṣ'àtúnṣe àwọn ojúewé tó tó tàbí tògùnju 32 kb lọ.
Ẹ jọ̀wọ́ ẹ rò ó wò bóyá ẹ lè fọ́ ojúewé ọ̀ún sí abala kéékèké.'''",
'templatesused'          => 'Àwọn àdàkọ tí a lò lórí ojúewé yìí:',
'templatesusedpreview'   => 'Àwọn àdàkọ tí a lò nìnú àgbéyẹ́wò yìí:',
'template-protected'     => '(aláàbò)',
'template-semiprotected' => '(aláàbò díẹ̀)',
'nocreatetext'           => "{{SITENAME}} ti pààlà ààyè láti ṣ'èdá ojúewé tuntun.
Ẹ le padà sẹ́yìn kí ẹ ṣ'àtúnṣe ojúewé tó wà, tàbí [[Special:UserLogin|kí ẹ wọlé tàbí kí ẹ ṣ'èdá àpamọ́]].",
'recreate-deleted-warn'  => "'''Ìkìlọ̀: Ẹ̀ ún ṣ'èdá ojúewé tí a ti parẹ́ tẹ́lẹ̀.'''

Ẹ gbọ́dọ̀ gberò bóyá ó bójúmu láti tẹ̀síwájú pẹ̀lú àtúnṣe ojúewé yìí.
Àkọsílẹ̀ ìparẹ́ nìyí fún ìrọ̀rùn:",

# Account creation failure
'cantcreateaccounttitle' => 'Ìforúkọsílẹ̀ kò se é se',

# History pages
'viewpagelogs'           => 'Ẹ wo àkọsílẹ̀ fún ojúewé yìí',
'currentrev'             => 'Àtúnyẹ̀wò ìsinsìnyí',
'revisionasof'           => 'Àtúnyẹ̀wò ní $1',
'revision-info'          => "Àtúnyẹ̀wò ní $1 l'átọwọ́ $2", # Additionally available: $3: revision id
'previousrevision'       => '← Àtúnyẹ̀wò tópẹ́ju',
'nextrevision'           => 'Àtúnyẹ̀wò tótuntunju →',
'currentrevisionlink'    => 'Àtúnyẹ̀wò ìsinsìnyí',
'cur'                    => 'lọ́wọ́',
'next'                   => 'tókàn',
'last'                   => 'tẹ́lẹ̀',
'page_first'             => 'àkọ́kọ́',
'page_last'              => 'tógbẹ̀yìn',
'history-fieldset-title' => 'Ìtàn Ìṣíwò',
'deletedrev'             => '[tiparẹ́]',
'histfirst'              => 'Pípẹ́jùlọ',
'histlast'               => 'Tuntunjùlọ',
'historyempty'           => '(òfo)',

# Revision feed
'history-feed-title'          => 'Ìtàn àtúnyẹ̀wò',
'history-feed-description'    => 'Ìtàn àtúnyẹ̀wò fún ojúewé yìí ní orí wiki',
'history-feed-item-nocomment' => '$1 ní $2', # user at time

# Revision deletion
'rev-delundel'      => 'fihàn/bòmọ́lẹ̀',
'pagehist'          => 'Ìtàn ojúewé',
'deletedhist'       => 'Ìtàn ìparẹ́',
'revdelete-summary' => 'àkótán àtúnṣe',
'revdelete-uname'   => 'orúkọ oníṣe',

# Diffs
'history-title'           => 'Ìtàn àtúnyẹ̀wò fún "$1"',
'difference'              => '(Ìyàtọ̀ láàrin àwọn àtúnyẹ́wò)',
'lineno'                  => 'Ìlà $1:',
'compareselectedversions' => 'Ìfiwéra àwọn àtúnṣe ìṣàyàn',
'editundo'                => 'dápadà',
'diff-movedto'            => 'tiyípò sí $1',

# Search results
'searchresults'             => 'Àwọn èsì àwáàrí',
'searchresults-title'       => 'Àwọn èsì àwáàrí fún "$1"',
'searchsubtitle'            => 'Ẹ ṣ\'àwáàrí fun \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|gbogbo ojúewé tó bẹ̀rẹ̀ pẹ̀lu "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|gbogbo ojúewé tó jápọ̀ mọ́ "$1"]])',
'searchsubtitleinvalid'     => "Ẹ ṣ'àwáàrí fun '''$1'''",
'noexactmatch'              => "'''Kò sí ojúewé pẹ̀lú àkọlé \"\$1\".'''
Ẹ le [[:\$1|ṣ'èdá ojúewé yìí]].",
'noexactmatch-nocreate'     => "'''Kò sí ojúewé pẹ̀lú àkọlé \"\$1\".'''",
'prevn'                     => 'titẹ́lẹ̀ $1',
'nextn'                     => 'tókàn $1',
'viewprevnext'              => 'Ẹ wo ($1) ($2) ($3)',
'searchhelp-url'            => 'Help:Àwon ohunnú',
'search-result-size'        => '$1 ({{PLURAL:$2|ọ̀rọ̀ 1|àwọn ọ̀rọ̀ $2}})',
'search-section'            => '(abala $1)',
'search-interwiki-more'     => '(rẹ́rẹ́)',
'search-mwsuggest-enabled'  => 'pẹ̀lú ìyànjú',
'search-mwsuggest-disabled' => 'kò sí ìyànjú',
'search-relatedarticle'     => 'Tóbáramu',
'searchrelated'             => 'tóbáramu',
'searchall'                 => 'gbogbo',
'powersearch'               => 'Ṣe àwáàrí',
'powersearch-legend'        => 'Àwáàrí gíga',
'powersearch-ns'            => 'Àwáàrí nínú orúkọàyè:',
'powersearch-redir'         => 'Àkójọ àwọn àtúnjúwe',
'powersearch-field'         => 'Àwáàrí fún',

# Preferences page
'preferences'          => 'Àwọn ìfẹ́ràn',
'mypreferences'        => 'Àwọn ìfẹ́ràn mi',
'prefs-edits'          => 'Iye àwọn àtúnṣe:',
'prefsnologin'         => 'Ẹ kò tíì wọlé',
'prefsnologintext'     => 'Ẹ gbọ́dọ̀ <span class="plainlinks">[{{fullurl:Special:UserLogin|returnto=$1}} wọlé]</span> láti to àwọn ìfẹ́ràn oníṣe.',
'changepassword'       => 'Ìyípadà ọ̀rọ̀ìpamọ́',
'skin'                 => 'Skin (Àwọ̀)',
'dateformat'           => 'Ìṣájúètò ọjọ́',
'datedefault'          => 'Kò sí ìfẹ́ràn',
'datetime'             => 'Ọjọ́ àti àkókò',
'prefs-personal'       => 'Ọ̀rọ̀ nípa oníṣe',
'prefs-rc'             => 'Àwọn àtúnṣe tuntun',
'prefs-watchlist'      => 'Ìmójútó',
'prefs-watchlist-days' => 'Ọjọ́ láti fihàn nínú ìmójútó:',
'saveprefs'            => 'Ìfipamọ́',
'resetprefs'           => 'Palẹ̀mọ́ àwọn àtúnṣe tí kò sì ní ìpamọ́',
'searchresultshead'    => 'Àwáàrí',
'savedprefs'           => 'Àwọn ìfẹ́ràn yín ti wà nípamọ́.',
'localtime'            => 'Àkókò ìbílẹ̀:',
'prefs-searchoptions'  => 'Àwọn ìyàn àwáàrí',
'prefs-namespaces'     => 'Àwọn orúkọàyè',
'files'                => 'Àwọn faili',

# Groups
'group'               => 'Àkójọpọ̀:',
'group-user'          => 'Àwọn oníṣe',
'group-autoconfirmed' => 'Àwọn oníṣe ìmúdájú fúnrawọn',
'group-bot'           => 'Àwọn Bot',
'group-sysop'         => 'Àwọn alámùójútó',

'grouppage-user'          => '{{ns:project}}:Àwọn oníṣe',
'grouppage-autoconfirmed' => '{{ns:project}}:Àwọn oníṣe ìmúdájú fùnrawọn',
'grouppage-bot'           => '{{ns:project}}:Àwọn Bot',
'grouppage-sysop'         => '{{ns:project}}:Àwọn alámùójútó',

# User rights log
'rightslog' => 'Àwọn ẹ̀tọ́ oníṣe',

# Recent changes
'nchanges'                       => '{{PLURAL:$1|àtúnṣe|àwọn àtúnṣe}} $1',
'recentchanges'                  => 'Àwọn àtúnṣe tuntun',
'recentchanges-feed-description' => 'Ẹ tẹ̀ lé àwọn àtúnṣe àìpẹ́ ọjọ́ sí wiki nínú àkótán feed yìí.',
'rcnote'                         => "Lábẹ́ yìí ni {{PLURAL:$1|àtúnṣe '''kan'''|àwọn àtúnṣe '''$1'''}} tó kẹ̀yìn ní ọjọ́ '''$2''' sẹ́yìn, ní ago $5, ọjọ́ $4.",
'rcnotefrom'                     => "Àwọn àtúnṣe láti ''''$2''' (títí dé '''$1''' hàn) lábẹ́.",
'rclistfrom'                     => 'Àfihàn àwọn àtúnṣe tuntun nípa bíbẹ̀rẹ̀ láti $1',
'rcshowhideminor'                => '$1 àwọn àtúnṣe kékéèké',
'rcshowhidebots'                 => '$1 àwọn bot',
'rcshowhideliu'                  => '$1 àwọn oníṣe tótiwọlé',
'rcshowhideanons'                => '$1 àwọn oníṣe aláìlórúkọ',
'rcshowhidepatr'                 => '$1 àwọn àtúnṣe ọlùṣọ́',
'rcshowhidemine'                 => '$1 àwọn àtúnṣe mi',
'rclinks'                        => "Ṣ'àfihàn àtúnṣe $1 tó kẹ̀yìn ní ọjọ́ $2 sẹ́yìn<br />$3",
'diff'                           => 'ìyàtọ̀',
'hist'                           => 'ìtàn',
'hide'                           => 'Ìbòmọ́lẹ̀',
'show'                           => 'Àfihàn',
'minoreditletter'                => 'k',
'newpageletter'                  => 'T',
'boteditletter'                  => 'b',
'rc_categories_any'              => 'Èyíkéyìí',
'newsectionsummary'              => '/* $1 */ abala tuntun',

# Recent changes linked
'recentchangeslinked'          => 'Àtúnṣe tó báramu',
'recentchangeslinked-title'    => 'Àtúnṣe tó báramu mọ́ "$1"',
'recentchangeslinked-noresult' => 'Kò sí ìyàtọ̀ nínú àwọn ojúewé ìjápọ̀ láàrin ìgbà tí ẹ sọ.',
'recentchangeslinked-summary'  => "Àkójọ àwọn àtúnṣe tí a sẹ̀sẹ̀ ṣe sí àwọn ojúewé tó jápọ̀ wá láti ojúewé pàtó kan (tàbí sí ìkan nìnú ẹ̀ka pàtó kan).
Àwọn ojúewé inú [[Special:Watchlist|ìmójútó yín]] jẹ́ '''kedere'''.",
'recentchangeslinked-page'     => 'Orúkọ ojúewé:',

# Upload
'upload'            => 'Ìrùsókè faili',
'uploadbtn'         => 'Ìrùsókè faili',
'reupload'          => 'Àtún-rùsókè',
'uploadnologin'     => 'Ẹ kò tíì wọlé',
'uploadnologintext' => 'Ẹ gbọ́dọ̀ [[Special:UserLogin|wọlè]] láti rùsókè faili.',
'uploaderror'       => 'Àsìse ìrùsókè',
'uploadlogpage'     => 'Àkọsílẹ̀ ìrùsókè',
'filename'          => 'Ọrúkọ faili',
'filedesc'          => 'Àkótán',
'fileuploadsummary' => 'Àkótán:',
'uploadedfiles'     => 'Àwọn faili tórùsókè',
'ignorewarning'     => 'Fojúfo ìkìlọ̀ sì fi faili pamọ́',
'ignorewarnings'    => 'Fojúfo ìkìlọ̀ tó wù kó jẹ́',
'minlength1'        => 'Ó kéréjù àwọn orúkọ faili gbọdọ̀ jẹ́ lẹ́tà kan.',
'uploadedimage'     => 'ti ru "[[$1]]" s\'ókè',

# Special:ListFiles
'listfiles'      => 'Àkójọ faili',
'listfiles_name' => 'Orúkọ',
'listfiles_user' => 'Oníṣe',

# File description page
'filehist'                  => 'Ìtàn faili',
'filehist-help'             => 'Ẹ kan ọjọ́/àsìkò kan láti wo faili òún bó ṣe hàn ní ìgbà na.',
'filehist-current'          => 'lọ́wọ́',
'filehist-datetime'         => 'Ọjọ́/Àsìkò',
'filehist-user'             => 'Oníṣe',
'filehist-dimensions'       => 'Ẹ̀gbẹ̀ẹ̀gbẹ́',
'filehist-filesize'         => 'Ìtóbi faili',
'filehist-comment'          => 'Àwísọ',
'imagelinks'                => 'Àwọn ìjápọ̀ faili',
'linkstoimage'              => '{{PLURAL:$1|Ojúewé yí|$1 Àwọn ojúewé yí}} jápọ̀ mọ́ àpò yí:',
'nolinkstoimage'            => 'Kò sí ojúewé tó jápọ̀ mọ́ faili yìí.',
'sharedupload'              => 'Faili yìí jẹ́ ìrùsókè láti $1 à ṣì le pin pẹ̀lú àwọn iṣẹ́owọ́ mìíràn tí wọ́n n lòó.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
'noimage'                   => 'Kò sí faili tí únjẹ́ báun, sùgbọ́n ẹ le ẹ̀ $1.',
'noimage-linktext'          => 'Ìrùsókè ẹyọkan',
'uploadnewversion-linktext' => 'Ẹ ṣe ìrùsókè àtúnṣe tuntun faili yìí',

# File deletion
'filedelete'        => 'Paarẹ́ $1',
'filedelete-submit' => 'Paarẹ́',

# MIME search
'mimesearch' => 'àwáàrí pẹ́lú MIME',
'download'   => 'ìrùsílẹ̀',

# List redirects
'listredirects' => 'Àkójọ àwọn àtúnjúwe',

# Unused templates
'unusedtemplates' => 'Àdàkọ àìlò',

# Random page
'randompage' => 'Ojúewé àrìnàkò',

# Statistics
'statistics' => 'Àwọn statistiki',

'disambiguations' => 'Àwọn ojúewé ìpínsọ́tọ̀',

'doubleredirects' => 'Àwọn àtúnjúwe ẹ̀mẹjì',

'brokenredirects' => 'Àwọn àtúnjúwe tótigé',

'withoutinterwiki' => 'Àwọn ojúewé tí kò ní ìjápọ̀ èdè',

'fewestrevisions' => 'Àwọn ojúewé pẹ̀lú àwọn àtúnyẹ̀wọ̀ tókéréjù',

# Miscellaneous special pages
'nbytes'                  => '$1 {{PLURAL:$1|byte|bytes}}',
'ncategories'             => '{{PLURAL:$1|ẹ̀ka|àwọn ẹ̀ka}} $1',
'nlinks'                  => '{{PLURAL:$1|ìjápọ̀|àwọn ìjápọ̀}} $1',
'nmembers'                => '{{PLURAL:$1|ará|àwọn ará}} $1',
'nrevisions'              => '{{PLURAL:$1|àtúnyẹ̀wò|àwọn àtúnyẹ̀wò}} $1',
'lonelypages'             => 'Àwọn ojúewé aláìlóbìí',
'lonelypagestext'         => 'Àwọn ojúewé wọ̀nyí kò ní ìjápọ̀ láti ọ̀dọ̀ àwọn ojúewé míràn nínú {{SITENAME}}.',
'uncategorizedpages'      => 'Àwọn ojúewé aláìlẹ́ka',
'uncategorizedcategories' => 'Àwọn ẹ̀ka aláìlẹ́ka',
'uncategorizedimages'     => 'Àwọn faili aláìlẹ́ka',
'uncategorizedtemplates'  => 'Àwọn àdàkọ aláìlẹ́ka',
'unusedcategories'        => 'Ẹ̀ka àìlò',
'unusedimages'            => 'Faili àìlò',
'popularpages'            => 'Ojúewé tógbajúmọ̀',
'wantedcategories'        => 'Àwọn ẹ̀ka aláìní',
'wantedpages'             => 'Àwọn ojúewé fún wíwá',
'mostlinked'              => 'Àwọn ojúewé tó ní ìjápọ̀ mọ́ jùlọ',
'mostlinkedcategories'    => 'Àwọn ẹ̀ka tó ní ìjápọ̀ mọ́ jùlọ',
'mostlinkedtemplates'     => 'Àwọn àdákọ tó ní ìjápọ̀mọ́ jùlọ',
'mostcategories'          => 'Àwọn ojúewé pẹ̀lú àwọn ẹ̀ka tópọ̀jùlọ',
'mostimages'              => 'Àwọn faili tó ní ìjápọ̀mọ́ jùlọ',
'mostrevisions'           => 'Àwọn ojúewé pẹ̀lu àwọn àtúnyẹ̀wò tópọ̀jùlọ',
'prefixindex'             => 'Gbogbo ojúewé tó ní ìtọ́ka ìpele',
'shortpages'              => 'Àwọn ojúewé kúkúrú',
'longpages'               => 'Ojúewé gúngùn',
'deadendpages'            => 'Àwọn ojúewé aláìníjàápọ́',
'protectedpages'          => 'Àwọn ojúewé aláàbò',
'listusers'               => 'Àkójọ àwọn oníṣe',
'newpages'                => 'Àwọn ojúewé tuntun',
'newpages-username'       => 'Orúkọ oníṣe:',
'ancientpages'            => 'Àwọn ojúewé tópẹ́jùlọ',
'move'                    => 'Yípò',
'movethispage'            => 'Yípò ojúewé yìí',

# Book sources
'booksources' => 'Àwọn ibi ìwẹ́',

# Special:Log
'specialloguserlabel'  => 'Oníṣe:',
'speciallogtitlelabel' => 'Àkọlé:',
'log'                  => 'Àwọn àkọsílẹ̀',
'all-logs-page'        => 'Gbogbo àkọsílẹ̀',

# Special:AllPages
'allpages'          => 'Gbogbo ojúewé',
'alphaindexline'    => '$1 dé $2',
'nextpage'          => 'Ojúewé tókàn ($1)',
'prevpage'          => 'Ojúewé sẹ́yìn ($1)',
'allpagesfrom'      => 'Àgbéhàn ojúewé tó bẹ̀rẹ̀ láti:',
'allarticles'       => 'Gbogbo ojúewé',
'allinnamespace'    => 'Gbogbo ojúewé ($1 namespace)',
'allnotinnamespace' => 'Gbogbo ojúewé (tí kòsí ní $1 namespace)',
'allpagessubmit'    => 'Ó yá',
'allpagesprefix'    => 'Ìgbéhàn àwọn ojúewé tóbẹ̀rẹ̀ pẹ̀lú:',

# Special:Categories
'categories' => 'Àwọn ẹ̀ka',

# E-mail user
'emailuser'    => 'Ẹ fi e-mail ránṣẹ́ sí oníṣe yìí',
'emailfrom'    => 'Láti:',
'emailto'      => 'Sí:',
'emailsubject' => 'Oríọ̀rọ̀:',
'emailmessage' => 'Ìránṣẹ́:',
'emailsend'    => 'Firánṣẹ́',

# Watchlist
'watchlist'         => 'Ìmójútó mi',
'mywatchlist'       => 'Ìmójútó mi',
'watchlistfor'      => "(fún '''$1''')",
'addedwatch'        => 'Ti fikún sí ìmójútó',
'addedwatchtext'    => "A ti ṣ'àfikún \"[[:\$1]]\" sí [[Special:Watchlist|ìmójútó]] yín.
A óò ṣ'àkójọ àwọn àtúnṣe ọjọ́wajú sí ojúewé yìí àti ojúewé ọ̀rọ̀ rẹ̀ sí bẹ̀. Bákanáà ojúewé náà yíò hàn '''kedere''' nìnú [[Special:RecentChanges|àkójọ àwọn àtúnṣe tuntun]] kó le ba à rọrùn láti rí.",
'removedwatch'      => 'Ti mú kúrò nínú ìmójútó',
'removedwatchtext'  => 'A ti yọ ojúewé "[[:$1]]" kúrò nínú [[Special:Watchlist|ìmójútó yín]].',
'watch'             => "M'ójútó",
'watchthispage'     => "M'ójútó ojúewé yi",
'unwatch'           => "Já'wọ́ ìmójútó",
'unwatchthispage'   => "Já'wọ́ ìmójútó ojúewé yi",
'watchlist-details' => '{{PLURAL:$1|Ojúewé $1|Àwọn ojúewé $1}} ló wà nínú ìmójútó yín, tí a kò bá ka àwọn ojúewé ọ̀rọ̀.',
'wlshowlast'        => 'Áfihàn wákàtí $1 sẹ́yìn ọjọ́ $2 sẹ́yìn $3',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Ún mójútó...',
'unwatching' => 'Jíjáwọ́ ìmójútó...',

'enotif_impersonal_salutation' => 'Oníṣe {{SITENAME}}',
'changed'                      => 'tiyípadà',
'created'                      => 'tiṣèdá',
'enotif_subject'               => '$PAGEEDITOR $CHANGEDORCREATED ojúewé $PAGETITLE lórí {{SITENAME}}',

# Delete
'deletepage'            => 'Pa ojúewé rẹ́',
'historywarning'        => 'Ìkìlọ̀: Ojúewé tí ẹ fẹ́ parẹ́ ní ìtàn:',
'actioncomplete'        => 'Ìmúṣe ti parí',
'deletedtext'           => 'A ti pa "<nowiki>$1</nowiki>" rẹ́.
Ẹ wo $2 fún àkọọ́lẹ̀ àwọn ìparẹ́ àìpẹ́.',
'deletedarticle'        => 'A ti pa "[[$1]]" rẹ́',
'dellogpage'            => 'Àkọsílẹ̀ ìparẹ́',
'deletecomment'         => 'Ìdí fún ìparẹ́:',
'deleteotherreason'     => 'Àwọn ìdí mìíràn:',
'deletereasonotherlist' => 'Ìdí mìíràn',

# Rollback
'rollbacklink' => 'yísẹ́yìn',

# Protect
'protectlogpage'              => 'Àkọsílẹ̀ àbò',
'protectcomment'              => 'Àríwí:',
'protectexpiry'               => 'Ìparí:',
'protect_expiry_invalid'      => 'Àkókò ìparí kò ní ìbámu.',
'protect_expiry_old'          => 'Ìgbà tó ti kọjá ni ìparí.',
'protect-unchain'             => 'Ṣíṣí ìyọ̀nda láti yípò',
'protect-text'                => "Ẹ lè wo, bẹ́ ẹ̀ sìni ẹ lè ṣ'àtúnṣe ibi àbò níbí fún ojúewé '''<nowiki>$1</nowiki>'''.",
'protect-locked-access'       => "Àpamọ́ yín kò ní àyè láti ṣ'àtúnṣe àwọn ibi àbò.
Bí a ṣe to ojúewé '''$1''' nì yí:",
'protect-default'             => 'Ẹ gba gbogbo àwọn oníṣe láàyè',
'protect-fallback'            => 'Ìyọ̀nda "$1" pọn dandan',
'protect-level-autoconfirmed' => 'Dínà àwọn oníṣe tuntun àti tíkòforúkọ sílẹ́',
'protect-level-sysop'         => 'Alámùójútó nìkan',
'protect-expiring'            => 'parí ní $1 (UTC)',
'protect-cantedit'            => "Ẹ kò le è ṣe àyípadà ibi àbò ojúewé yìí, nítorípé a kò yọ̀nda yín láti ṣ'àtúnṣe rẹ̀.",
'protect-expiry-options'      => 'wákàtí 2:2 hours,ọjọ́ 1:1 day,ọjọ́ 3:3 days,ọ̀ṣẹ̀ 1:1 week,ọ̀ṣẹ̀ 2:2 weeks,osù 1:1 month,osù 3:3 months,osù 6:6 months,ọdún 1:1 year,láìlópin:infinite', # display1:time1,display2:time2,...
'restriction-type'            => 'Ìyọ̀nda:',
'restriction-level'           => 'Ibi ìpàlà:',

# Undelete
'undeletebtn'  => 'Múpadà',
'undeletelink' => 'wòó/múpadà',

# Namespace form on various pages
'namespace'      => 'Orúkọàyè:',
'invert'         => 'Ìdorípo àsàyàn',
'blanknamespace' => '(Gbangba)',

# Contributions
'contributions' => 'Àwọn àfikún ẹnitínṣe',
'mycontris'     => 'Àwọn àfikún mi',
'contribsub2'   => 'Fún $1 ($2)',
'uctop'         => '(lókè)',
'month'         => 'Láti osù (àti sẹ́yìn):',
'year'          => 'Láti ọdún (àti sẹ́yìn):',

'sp-contributions-newbies'     => 'Àfihàn àwọn àfikún àwọn àpamọ́ tuntun nìkan',
'sp-contributions-newbies-sub' => 'Fún àwọn àpamọ́ tuntun',
'sp-contributions-blocklog'    => 'Àkọsílẹ̀ ìdínà',
'sp-contributions-search'      => 'Àwáàrí fún àwọn àfikún',
'sp-contributions-username'    => 'Ojúọ̀nà IP tàbí orúkọ oníṣe:',

# What links here
'whatlinkshere'       => 'Ìjápọ̀ mọ́ ojúewé yí',
'whatlinkshere-title' => 'Àwọn ojúewé tó jápọ̀ mọ́ "$1"',
'whatlinkshere-page'  => 'Ojúewé:',
'linkshere'           => "Àwọn ojúewé wọ̀nyí jápọ̀ mọ́ '''[[:$1]]''':",
'nolinkshere'         => "Kò sí ojúewé tó jápọ̀ mọ́ '''[[:$1]]'''.",
'isredirect'          => 'àtúnjúwe ojúewé',
'istemplate'          => 'ìkómọ́ra',
'whatlinkshere-prev'  => '{{PLURAL:$1|tẹ́lẹ̀|tẹ́lẹ̀ $1}}',
'whatlinkshere-next'  => '{{PLURAL:$1|tókàn|tókàn $1}}',
'whatlinkshere-links' => '← àwọn ìjápọ̀',

# Block/unblock
'blockip'       => 'Dínà oníṣe',
'ipbsubmit'     => 'Dènà oníṣe yìí',
'ipboptions'    => '2 wákàtí:2 hours,1 ọjọ́:1 day,3 ọjọ́:3 days,1 ọ̀ṣẹ̀:1 week,2 ọ̀ṣẹ̀:2 weeks,1 osù:1 month,3 osù:3 months,6 osù:6 months,1 ọdún:1 year,láìlópin:infinite', # display1:time1,display2:time2,...
'ipblocklist'   => 'Àwọn ojúọ̀nà IP àti orúkọ ọníṣe tí a dínà',
'blocklink'     => 'dínà',
'unblocklink'   => 'jáwọ́ ìdínà',
'contribslink'  => 'àfikún',
'blocklogpage'  => 'Àkosílẹ̀ ìdínà',
'blocklogentry' => 'ìdínà [[$1]] yíò parí ní $2 $3',

# Move page
'move-page'        => 'Yípò $1',
'move-page-legend' => 'Yípò ojúewé',
'movepagetalktext' => "Ojúewé ọ̀rọ̀ tó sopọ̀ mọ náà yíó yípò pọ̀ mọ '''àfibí:'''
*Tí ọ̀rọ̀ ojúewé tí kò jẹ́ òfo wà pẹ̀lú orúkọ tuntun, tàbí
*Ẹ mú àmí kúrò nínú àpótí ìṣàlẹ̀ yìí.

Tí ó bá jẹ́ báhun, ẹ gbúdọ̀ ṣe ìyípò rẹ̀ fúnra yín.",
'movearticle'      => 'Yípò ojúewé:',
'newtitle'         => 'Sí àkọlé tuntun:',
'move-watch'       => 'Mójútó ojúewé yìí',
'movepagebtn'      => 'Yípò ojúewé',
'pagemovedsub'     => 'Ìyípò ti já sí rere',
'movepage-moved'   => '<big>\'\'\'"$1" ti yípò sí "$2"\'\'\'</big>.', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
'articleexists'    => 'Ojúewé pẹ̀lú orúkọ un wà tẹ́lẹ̀, tàbí kójẹ́pé orúkọ tí ẹ yàn kò ní ìbámu.
Ẹ jọ̀wọ́ ẹ yan orúkọ mìíràn.',
'movedto'          => 'tiyípò sí',
'movetalk'         => 'Yípò ojúewé ọ̀rọ̀ rẹ̀',
'1movedto2'        => '[[$1]] ti yípò sí [[$2]]',
'movelogpage'      => 'Àkọsílẹ́ ìyípò',
'movereason'       => 'Ìdíẹ̀:',
'revertmove'       => 'dápadà',

# Export
'export' => 'Ìkójáde àwọn ojúewé',

# Namespace 8 related
'allmessages'     => 'Àwọn ìránṣẹ́ sistẹmu',
'allmessagesname' => 'Orúkọ',

# Thumbnails
'thumbnail-more' => 'Fẹ̀mú tóbi',

# Import log
'importlogpage' => 'Ìgbéwọlé àkọọ́lẹ̀',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Ojúewé oníṣe yín',
'tooltip-pt-mytalk'               => 'Ojúewé ọ̀rọ̀ yín',
'tooltip-pt-preferences'          => 'Àwọn ìfẹ́ràn mi',
'tooltip-pt-watchlist'            => 'Àkójọ àwọn ojúewé tí ẹ̀ ún mójútó bóyá wọ́nyí padà',
'tooltip-pt-mycontris'            => 'Àkójọ àwọn àfikún yín',
'tooltip-pt-login'                => 'A gbà yín níyànjú kí ẹwọlé, bótilẹ̀jẹ́pẹ́ kò pọndandan.',
'tooltip-pt-anonlogin'            => 'A gbàyín níyànjú láti wọlé, bótilẹ̀jẹ́pé kò ṣe dandan.',
'tooltip-pt-logout'               => 'Ìbọ́sódé',
'tooltip-ca-talk'                 => 'Ìfọ̀rọ̀wérọ̀ nípa ohun inú ojúewé yìí',
'tooltip-ca-edit'                 => 'Ẹ le ṣe àtúnṣe sí ojúewé yìí.
Ẹ jọ̀wọ́ ẹ lo bọtini àyẹ̀wò kí ẹ tó fipamọ́.',
'tooltip-ca-addsection'           => 'Ẹ bẹ̀rẹ̀ abẹlẹ tuntun',
'tooltip-ca-viewsource'           => 'Àbò wà lórí ojúewé yìí.
Ẹ le wo àmìọ̀rọ̀ rẹ̀.',
'tooltip-ca-protect'              => 'Dáàbòbo ojúewé yìí',
'tooltip-ca-delete'               => 'Pa ojúewé yìí rẹ́',
'tooltip-ca-move'                 => 'Yípò ojúewé yìí padà',
'tooltip-ca-watch'                => "Ṣ'àfikún ojúewé yìí mọ́ ìmójútó yín",
'tooltip-ca-unwatch'              => 'Ẹ yọ ojúewé yìí kúrò nínú ìmójútó yín',
'tooltip-search'                  => "Ṣ'àwáàrí nínú {{SITENAME}}",
'tooltip-search-go'               => 'Lọ sí ojúewé tó ní orúkọ yìí tí ọ́ bá wà',
'tooltip-search-fulltext'         => 'Ṣe àwáàrí nínú àwọn ojúewé fún ìkọ yìí',
'tooltip-p-logo'                  => 'Ojúewé Àkọ́kọ́',
'tooltip-n-mainpage'              => 'Ẹ ṣe àbẹ̀wò sí Ojúewé Àkọ́kọ́',
'tooltip-n-portal'                => 'Ẹ̀kúnrẹ́rẹ́ nípa iṣẹ́ọwọ́ yìí',
'tooltip-n-currentevents'         => 'Ìròhìn lọ́wọ́lọ́wọ́',
'tooltip-n-recentchanges'         => 'Àkójọ àwọn àtúnṣe tuntun nínú wiki.',
'tooltip-n-randompage'            => 'Ẹ ṣe àrìnàkò ojúewé kan',
'tooltip-n-help'                  => 'Fún ìrànlọ́wọ́.',
'tooltip-t-whatlinkshere'         => "Àkójọ gbogbo ojúewé wiki tó jápọ̀ s'íbí",
'tooltip-t-contributions'         => 'Ẹ wo àkójọ àwọn àfikún oníṣe yìí',
'tooltip-t-emailuser'             => 'Ẹ fi e-mail ránṣẹ́ sí oníṣe yìí',
'tooltip-t-upload'                => 'Ìrùsókè àwọn faili',
'tooltip-t-specialpages'          => 'Àkójọ gbogbo àwọn ojúewé pàtàkì',
'tooltip-t-print'                 => "Ojúewé tí ó ṣe é tẹ̀ ṣ'íwèé",
'tooltip-ca-nstab-user'           => 'Ẹ wo ojúewé oníṣe',
'tooltip-ca-nstab-special'        => "Ojúewé yìí ṣe pàtàkì, ẹ kò le è ṣ'àtúnṣe rẹ̀",
'tooltip-ca-nstab-project'        => 'Ẹ wo ojúewé iṣẹ́ọwọ́',
'tooltip-ca-nstab-image'          => 'Ẹ wo ojúewé faili',
'tooltip-ca-nstab-template'       => 'Ẹ wo àdákọ náà',
'tooltip-ca-nstab-help'           => 'Ẹ wo ojúewé ìrànlọ́wọ́',
'tooltip-ca-nstab-category'       => 'Ẹ wo ẹ́ka ojúewé',
'tooltip-minoredit'               => "Ṣ'àmì sí èyí gẹ́gẹ́ bi àtúnṣe kékeré",
'tooltip-save'                    => 'Àfipamọ́ àwọn àtúnṣe',
'tooltip-preview'                 => 'Àyẹ̀wò àwọn àtúnṣe yín, ẹ jọ̀wọ́ ẹ kọ́kọ́ lo è yí kí ẹ tó fipamọ́!',
'tooltip-diff'                    => 'Ìfihàn àwọn àtúnṣe tí ẹ ṣe sí ìkọ yìí.',
'tooltip-compareselectedversions' => 'Ẹ wo ìyàtò láàrin àwọn àtúnṣe tí a ṣàyàn fún ojúewé yìí.',
'tooltip-watch'                   => "Ẹ ṣ'àfikún ojúewé yìí mọ́ ìmójútó yín",

# Attribution
'siteuser'         => '$1 oníṣe lórí {{SITENAME}}',
'lastmodifiedatby' => 'Igba ti a se atunse si ojuewe yi gbeyin ni $2, $1 by $3.', # $1 date, $2 time, $3 user

# Browsing diffs
'previousdiff' => '← Àtúnṣe tópẹ́jù',
'nextdiff'     => 'Àtúnṣe tótuntunjù →',

# Media information
'file-info-size'       => '($1 × $2 pixel, ìtóbi faili: $3, irú MIME: $4)',
'file-nohires'         => '<small>Kò sí ìgbéhàn gíga jù báun lọ.</small>',
'svg-long-desc'        => '(faili SVG, pẹ̀lú $1 × $2 pixels, ìtòbi faili: $3)',
'show-big-image'       => 'Pẹ̀lú ìgbéhàn gíga',
'show-big-image-thumb' => '<small>Ìtóbi àyẹ̀wò yìí: $1 × $2 pixels</small>',

# Special:NewFiles
'newimages' => 'Ọ̀dẹ̀dẹ̀ àwòrán àwọn faili tuntun',

# Metadata
'metadata'          => 'Metadata',
'metadata-expand'   => 'Àfihàn ẹ̀kúnrẹ́rẹ́',
'metadata-collapse' => 'Ìbòmọ́lẹ̀ ẹ̀kúnrẹ́rẹ́',

# External editor support
'edit-externally-help' => '(Ẹ wo [http://www.mediawiki.org/wiki/Manual:External_editors ìlànà ìṣètò] fún ẹ̀kúnrẹ́rẹ́)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'gbogbo',
'namespacesall' => 'gbogbo',
'monthsall'     => 'gbogbo',

# E-mail address confirmation
'confirmemail'          => "Ṣè'múdájú ojúọ̀nà e-mail",
'confirmemail_noemail'  => 'Ẹ kò ti to ojúọ̀nà e-mail tó ní bámu nínú [[Special:Preferences|ìfẹ́ràn oníṣe]] yín.',
'confirmemail_send'     => 'Fi àmìọ̀rọ̀ ìmúdájú ránṣẹ́',
'confirmemail_sent'     => 'E-mail ti ránṣẹ́ ìmúdájú.',
'confirmemail_oncreate' => 'A ti fi àmìọ̀rọ̀ ìmúdájú ránṣẹ́ sí ojúọ̀nà e-mail yín.
Àmìọ̀rọ̀ yìí kò pọndandan láti mú yín wọlé, sùgbọ́n ẹ gbọ́dọ̀ mu padà kí gbogbo àwọn ohun inú wiki yìí tó dúró lórí e-mail ó tó lè ṣiṣẹ́.',
'confirmemail_loggedin' => 'Ojúọ̀nà e-mail yín ti dájú.',
'confirmemail_subject'  => 'Ìmúdájú ojúọ̀nà e-mail fún {{SITENAME}}',

# Watchlist editing tools
'watchlisttools-view' => 'Ẹ wo àwon àtúnṣe tóbaamu',
'watchlisttools-edit' => 'Ìwò àti àtúnṣe ìmójútó',
'watchlisttools-raw'  => "Ẹ ṣ'àtúnṣe àkójọ ìmójútó látìbẹ̀rẹ̀",

# Special:Version
'version' => 'Àtúnṣe', # Not used as normal message but as header for the special page itself

# Special:SpecialPages
'specialpages'                   => 'Àwọn ojúewé pàtàkì',
'specialpages-group-maintenance' => 'Àwọn ìjábọ̀ ìtọ́jú',
'specialpages-group-login'       => 'Ìwọlé / ìforúkọ sílẹ́',
'specialpages-group-pages'       => 'Àkójọ àwọn ojúewé',
'specialpages-group-pagetools'   => 'Àwọn irinṣẹ́ ojúewé',

# Special:BlankPage
'blankpage' => 'Ojúewé òfo',

);
